@@ -1,19 +1,7 @@
 /*
-    Copyright (C) 2013  David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2013 David Edmundson <davidedmundson@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "personpluginmanager.h"
@@ -38,8 +26,8 @@ public:
     QHash<QString /* SourceName*/, BasePersonsDataSource *> dataSourcePlugins;
 
     void loadDataSourcePlugins();
-    bool m_autoloadDataSourcePlugins;
-    bool m_loadedDataSourcePlugins;
+    bool m_autoloadDataSourcePlugins = true;
+    bool m_loadedDataSourcePlugins = false;
     QMutex m_mutex;
 
 };
@@ -47,8 +35,6 @@ public:
 Q_GLOBAL_STATIC(PersonPluginManagerPrivate, s_instance)
 
 PersonPluginManagerPrivate::PersonPluginManagerPrivate()
-    : m_autoloadDataSourcePlugins(true)
-    , m_loadedDataSourcePlugins(false)
 {
 }
 
